@@ -134,3 +134,25 @@ def get_user_email(token: AnyStr=None) -> str:
     if not isinstance(mail_str, str):
         raise ValueError(f'Uid key is mapped to {repr(mail_str)} (type: {type(mail_str)}) value in claims')
     return mail_str
+
+def get_user_uid(token: AnyStr=None) ->str:
+    """
+    Retrieve user firebase uid from connexion header.
+
+    Arguments:
+        token {AnyStr} -- Token provided by the connexion header
+
+    Raises:
+        ValueError -- If we failed to retrieve token
+
+    Returns:
+        [str] -- user uid
+    """
+
+    if token is None:
+        token = request.headers.get('Authorization', '').split(' ').pop()
+        if not token:
+            raise ValueError(f"Failed to retrieve token from http header from token {request.headers.get('Authorization', '')}")
+    claims = firebase_auth.verify_id_token(token)
+
+    return claims['uid']
